==> haskell-test-framework-quickcheck2-0.3.0.4-16-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-test-framework-quickcheck2.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: test-framework-quickcheck2
version: 0.3.0.4
id: test-framework-quickcheck2-0.3.0.4-14Ni3Xfs7Nr9JiyBR8TTGI
key: test-framework-quickcheck2-0.3.0.4-14Ni3Xfs7Nr9JiyBR8TTGI
license: BSD-3-Clause
maintainer: Haskell Libraries <libraries@haskell.org>
author: Max Bolingbroke <batterseapower@hotmail.com>
homepage: http://haskell.github.io/test-framework/
synopsis: QuickCheck-2 support for the test-framework package.
description:
    Allows @QuickCheck-2@ properties to be used with the </package/test-framework test-framework package>.
category: Testing
abi: 1053ea4e04fa622c570f45faa84c5793
exposed: True
exposed-modules:
    Test.Framework.Providers.QuickCheck2
import-dirs: /usr/lib/ghc-8.4.3/site-local/test-framework-quickcheck2-0.3.0.4
library-dirs: /usr/lib/ghc-8.4.3/site-local/test-framework-quickcheck2-0.3.0.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/test-framework-quickcheck2-0.3.0.4
hs-libraries: HStest-framework-quickcheck2-0.3.0.4-14Ni3Xfs7Nr9JiyBR8TTGI
depends:
    test-framework-0.8.2.0-B3Pl5gcgTqTDKXxK4e8i9L
    QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr base-4.11.1.0
    extensible-exceptions-0.1.1.4-J1OT5xNWUKn5hZNwjN7aJn
    random-1.1-9LLJAJa4iQFLJiLXBOBXBV
abi-depends: test-framework-0.8.2.0-B3Pl5gcgTqTDKXxK4e8i9L=a878356130f1ca63c8dfd2958692d4c3
             QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr=0b62adbb61d61aac8d449588192e831b
             base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             extensible-exceptions-0.1.1.4-J1OT5xNWUKn5hZNwjN7aJn=bad6d8216f3724a304dcc80fb49d8538
             random-1.1-9LLJAJa4iQFLJiLXBOBXBV=8df244958947206247b1dd733653312e
haddock-interfaces: /usr/share/doc/haskell-test-framework-quickcheck2/html/test-framework-quickcheck2.haddock
haddock-html: /usr/share/doc/haskell-test-framework-quickcheck2/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-test-framework-quickcheck2-0.3.0.5-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-test-framework-quickcheck2.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: test-framework-quickcheck2
version: 0.3.0.5
id: test-framework-quickcheck2-0.3.0.5-FR5KDUVjOpyEnFTc2WAClr
key: test-framework-quickcheck2-0.3.0.5-FR5KDUVjOpyEnFTc2WAClr
license: BSD-3-Clause
maintainer: Haskell Libraries <libraries@haskell.org>
author: Max Bolingbroke <batterseapower@hotmail.com>
homepage: http://haskell.github.io/test-framework/
synopsis: QuickCheck-2 support for the test-framework package.
description:
    Allows @QuickCheck-2@ properties to be used with the </package/test-framework test-framework package>.
category: Testing
abi: 9ceeaa0a19ba6a0a4f92cc978246974c
exposed: True
exposed-modules:
    Test.Framework.Providers.QuickCheck2
import-dirs: /usr/lib/ghc-8.4.3/site-local/test-framework-quickcheck2-0.3.0.5
library-dirs: /usr/lib/ghc-8.4.3/site-local/test-framework-quickcheck2-0.3.0.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/test-framework-quickcheck2-0.3.0.5
hs-libraries: HStest-framework-quickcheck2-0.3.0.5-FR5KDUVjOpyEnFTc2WAClr
depends:
    test-framework-0.8.2.0-2cH7n9Q2Mth9lgEN2DsHAS
    QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr base-4.11.1.0
    extensible-exceptions-0.1.1.4-J1OT5xNWUKn5hZNwjN7aJn
    random-1.1-9LLJAJa4iQFLJiLXBOBXBV
abi-depends: test-framework-0.8.2.0-2cH7n9Q2Mth9lgEN2DsHAS=2f81401ccdfa70891d0dfe57e5f819ee
             QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr=0b62adbb61d61aac8d449588192e831b
             base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             extensible-exceptions-0.1.1.4-J1OT5xNWUKn5hZNwjN7aJn=bad6d8216f3724a304dcc80fb49d8538
             random-1.1-9LLJAJa4iQFLJiLXBOBXBV=8df244958947206247b1dd733653312e
haddock-interfaces: /usr/share/doc/haskell-test-framework-quickcheck2/html/test-framework-quickcheck2.haddock
haddock-html: /usr/share/doc/haskell-test-framework-quickcheck2/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
